REST API
========

.. automodule:: api.resources

.. autoclass:: UserResource
    :members:
    
.. autoclass:: RegisterResource
    :members:
    
.. autoclass:: TrackerResource
    :members:
    
.. autoclass:: CourseResource
    :members:
    
.. autoclass:: CourseTagResource
    :members:
    
.. autoclass:: ScheduleResource
    :members:
    
.. autoclass:: TagResource
    :members:
    
.. autoclass:: ActivityScheduleResource
    :members:
    
.. autoclass:: PointsResource
    :members:

.. autoclass:: BadgesResource
    :members:
    
.. autoclass:: AwardsResource
    :members:
    
.. autoclass:: ScorecardResource
    :members:
    
.. automodule:: quiz.api.resources

.. autoclass:: QuizResource
    :members:
    
.. autoclass:: QuizQuestionResource
    :members:
    
.. autoclass:: QuestionResource
    :members:
    
.. autoclass:: QuestionPropsResource
    :members:
    
.. autoclass:: ResponseResource
    :members:
    
.. autoclass:: ResponsePropsResource
    :members:
    
.. autoclass:: QuizPropsResource
    :members:
    
.. autoclass:: QuizAttemptResponseResource
    :members:
    
.. autoclass:: QuizAttemptResource
    :members: